# (c) 2023 Christophe Gueneau

from time import sleep_ms

class Driver_moteur_grove():
    def __init__(self, i2c):
        self._i2c = i2c
        sleep_ms(10)
        self.m1_dir = self.m2_dir = 1
        self.m1_vit = self.m2_vit = 0
        self._ecriture_registre(0x84, 0x02, 0x00)     # PWM à 3921 Hz


    def _ecriture_registre(self, adresse_registre, val1, val2):
        buf = bytes((adresse_registre, val1, val2))
        self._i2c.writeto(0x0f, buf)
        sleep_ms(4)

    def vit(self, mot, vit):
        if mot == 1:
            self.m1_vit = vit
        if mot == 2:
            self.m2_vit = vit

        # direction
        if self.m1_vit >= 0 and self.m2_vit >= 0:
            self._ecriture_registre(0xaa, 0x0a, 0x00)
        if self.m1_vit >= 0 and self.m2_vit < 0:
            self._ecriture_registre(0xaa, 0x06, 0x00)
        if self.m1_vit < 0 and self.m2_vit >= 0:
            self._ecriture_registre(0xaa, 0x09, 0x00)
        if self.m1_vit < 0 and self.m2_vit < 0:
            self._ecriture_registre(0xaa, 0x05, 0x00)

        # vitesse
        self._ecriture_registre(0x82, int(abs(self.m1_vit)/100*255), int(abs(self.m2_vit)/100*255))



if __name__ == '__main__':

    from machine import Pin, I2C
    from time import sleep_ms

    # Crée un objet I2C
    i2c0 = I2C(0, scl=Pin(9), sda=Pin(8), freq=400000)    # I2C0 utilisé  

    # Crée un objet Lcd_rgb_grove
    dm = Driver_moteur_grove(i2c0)

    while True:
        # tout droit en avant
        dm.vit(1, 50)      # sens 1 moteur 1 à 50%
        dm.vit(2, 50)      # sens 2 moteur 2 à 50%
        sleep_ms(2000)

        # pour tourner en avançant
        dm.vit(1, 50)      # sens 1 moteur 1 à 50%
        dm.vit(2, 10)      # sens 2 moteur 2 à 10%
        sleep_ms(2000)

        # tout droit en arière
        dm.vit(1, -50)     # sens 1 moteur 1 à 50%
        dm.vit(2, -50)     # sens 2 moteur 2 à 50%
        sleep_ms(2000)

        # arrêt
        dm.vit(1, 0)       # moteur 1 à 0%
        dm.vit(2, 0)       # moteur 2 à 0%
        sleep_ms(2000)
       
       





